Release History
===============

2.0.2
----------------------
* Fixed all setup.py and setup.cfg.
* Released to pypi

2.0.1
----------------------
* Initial tag

2.0.0
----------------------

* Convert to RESTCONF api (@hmvp)

1.3.0
----------------------

* Add support for disabling SSL verification for NSO servers with self-signed certificates (@acidjunk)
